aboutsummaryrefslogtreecommitdiff
path: root/bin/level_calc.py
diff options
context:
space:
mode:
authorSelene ToyKeeper2019-03-26 11:55:21 -0600
committerSelene ToyKeeper2019-03-26 11:55:21 -0600
commita1651c1dd602baeb77ae6f17180283049350a419 (patch)
tree287015c7afcca43f779700e0dacbf43f8036579f /bin/level_calc.py
parentMade default level configurable per build target, made moon hint blip a bit m... (diff)
parentupdated D18 config to 03-21 version (diff)
downloadanduril-a1651c1dd602baeb77ae6f17180283049350a419.tar.gz
anduril-a1651c1dd602baeb77ae6f17180283049350a419.tar.bz2
anduril-a1651c1dd602baeb77ae6f17180283049350a419.zip
merged Emisar D18 branch, which also includes a bunch of Anduril refactoring
Diffstat (limited to 'bin/level_calc.py')
-rwxr-xr-xbin/level_calc.py5
1 files changed, 3 insertions, 2 deletions
diff --git a/bin/level_calc.py b/bin/level_calc.py
index c903800..7635595 100755
--- a/bin/level_calc.py
+++ b/bin/level_calc.py
@@ -5,7 +5,7 @@ from __future__ import print_function
import math
interactive = False
# supported shapes: ninth, fifth, cube, square, log_e, log_2
#ramp_shape = 'cube'
@@ -14,7 +14,7 @@ def main(args):
"""
# Get parameters from the user
questions_main = [
- (str, 'ramp_shape', 'cube', 'Ramp shape? [cube, square, fifth, ninth, log_e, log_2]'),
+ (str, 'ramp_shape', 'cube', 'Ramp shape? [cube, square, fifth, seventh, ninth, log_e, log_2]'),
(int, 'num_channels', 1, 'How many power channels?'),
(int, 'num_levels', 4, 'How many total levels do you want?'),
]
@@ -169,6 +169,7 @@ def get_value(text, default, args):
shapes = dict(
ninth = (lambda x: x**9, lambda x: math.pow(x, 1/9.0)),
+ seventh= (lambda x: x**7, lambda x: math.pow(x, 1/7.0)),
fifth = (lambda x: x**5, lambda x: math.pow(x, 1/5.0)),
cube = (lambda x: x**3, lambda x: math.pow(x, 1/3.0)),
square = (lambda x: x**2, lambda x: math.pow(x, 1/2.0)),
@@ -5,7 +5,7 @@ from __future__ import print_function
import math
interactive = False
-# supported shapes: ninth, fifth, cube, square, log_e, log_2
+# supported shapes: ninth, seventh, fifth, cube, square, log_e, log_2
#ramp_shape = 'cube'